#
# spec file for package python-manilaclient
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global sname python-manilaclient
Name:           python-manilaclient
Version:        1.11.0
Release:        1.1
Summary:        Client Library for OpenStack Share API
License:        Apache-2.0
Group:          Development/Languages/Python
Url:            https://launchpad.net/%{sname}
Source0:        https://pypi.io/packages/source/p/%{sname}/%{sname}-%{version}.tar.gz
BuildRequires:  openstack-macros
BuildRequires:  openstack-tempest
BuildRequires:  python-ddt >= 1.0.1
BuildRequires:  python-devel
BuildRequires:  python-fixtures >= 3.0.0
BuildRequires:  python-mock >= 2.0
BuildRequires:  python-openstackclient >= 2.1.0
BuildRequires:  python-oslotest >= 1.10.0
BuildRequires:  python-testrepository >= 0.0.18
BuildRequires:  python-testtools >= 1.4.0
Requires:       python-Babel >= 2.3.4
Requires:       python-PrettyTable >= 0.7
Requires:       python-keystoneclient >= 2.0.0
Requires:       python-oslo.config >= 3.14.0
Requires:       python-oslo.log >= 1.14.0
Requires:       python-oslo.serialization >= 1.10.0
Requires:       python-oslo.utils >= 3.16.0
Requires:       python-requests >= 2.10.0
Requires:       python-simplejson >= 2.2.0
Requires:       python-six >= 1.9.0
BuildArch:      noarch

%description
Client library and command line utility for interacting with Openstack
Share API.

%package doc
Summary:        Documentation for OpenStack Share API Client
Group:          Documentation
BuildRequires:  python-Sphinx
BuildRequires:  python-oslosphinx >= 2.5.0

%description      doc
Client library and command line utility for interacting with Openstack
Share API.
This package contains auto-generated documentation.

%prep
%setup -q -n %{sname}-%{version}

%build
%{py2_build}

%{__python2} setup.py build_sphinx
# remove the sphinx-build leftovers
rm -rf doc/build/html/.{doctrees,buildinfo}

%install
%{py2_install}
# man page
install -p -D -m 644 doc/build/man/python-manilaclient.1 %{buildroot}%{_mandir}/man1/python-manilaclient.1
# bash completion
install -p -D -m 644 tools/manila.bash_completion %{buildroot}%{_sysconfdir}/bash_completion.d/%{name}

%check
%{__python2} setup.py testr

%files
%doc README.rst
%license LICENSE
%{python2_sitelib}/manilaclient
%{python2_sitelib}/*.egg-info
%{_sysconfdir}/bash_completion.d/%{name}
%{_mandir}/man1/python-manilaclient.1.gz
%{_bindir}/manila

%files doc
%license LICENSE
%doc doc/build/html

%changelog
* Tue Sep  6 2016 tbechtold@suse.com
  update to version 1.11.0
  * add access_key to access_list API's response
  * Use consistent env variable naming
  * Add validation for token and bypass_url
  * Remove ordereddict from test-requirements.txt
  * Add share type change to Share Migration CLI
  * Add snapshot instances admin CLIs
  * Update Share Migration CLI
  * Add columns support for share-replica-list
  * Replace OpenStack LLC with OpenStack Foundation
  * Updated from global requirements
* Thu Sep  1 2016 tbechtold@suse.com
  update to version 1.10.0
  * Remove discover from test-requirements
  * Replace tempest-lib with tempest.lib
  * Fix list access function comment
  * Remove white space between print and ()
  * Add possibility to provide auth token via CLI
  * Added CONTRIBUTING.rst file to the project
  * Fix typos
  * manila list --all-tenants should display projectID
  * Updated from global requirements
  * Handle error for missing minor api version
  * Fix view of doc info for functional tests
  * Remove iso8601 and pycrypto useless requirements
  * Add support for releasenotes
  * Update the home-page with developer documentation
  * Hacking version update and pep8 issues fix
  * Define experimental API header on python client level instead of CLI
  * Make dict.keys() PY3 compatible
  * UnsupportedVersion Thrown for Supported Version
  * [CI] Fix devstack hooks to unblock CI
  * Fix "single_alias" action for CLI commands
- update _service and switch to upstream spec template
* Thu Mar 24 2016 tbechtold@suse.com
- update to 1.8.1:
  * Revert fix access rules functional tests
  * Fix typos
  * Microversion 'cephx' access type in API v2
  * Fixed description of auth_url config parameter
  * Add 'cephx' authentication type
  * Added new CLI commands for Share migration
  * Use 'example' instead of 'foo' or 'bar' in help outputs
  * Annotate CLI commands for experimental features
  * CLI for manage/unmanage snapshot
  * Support preferred export locations in Manila CLI
  * Client Support for Manila Share Replication
  * Fix post_test_hook.sh script auth error
  * Updated from global requirements
  * To tag all the Admin-only APIs as Admin only
  * Fix function name
  * Add missing element in functional test
  * Eliminate unnecessary character
  * Fix functional tests to respect insecure SSL option
  * Updated from global requirements
  * Fix Access Rules functional tests
  * Add support of export location metadata feature
  * Set default access_level to rw in help
  * Updated from global requirements
* Thu Mar  3 2016 tbechtold@suse.com
- update to 1.7.0:
  * Remove argparse from requirements
  * Fix backwards compatibility for v1 API imports
  * Keep using the session we had when creating keystone client
  * Add uppercase env var names for consistency
  * Fix the "OpenStack CLI guide" link
  * Updated from global requirements
  * Add debug testenv in tox
  * Removes MANIFEST.in as it is not needed explicitly by PBR
  * Updated from global requirements
  * Replace deprecated LOG.warn with warning
  * Remove vim header from source files
  * Show selected columns in list commands of manila
  * Remove unreachable code from unit tests
  * Client fix for api_version in positional and kwarg
  * Replace assertEqual(None, *) with assertIsNone in tests
  * Updated from global requirements
  * Fix microversion comparison approach in functional tests
  * Drop py33 support
  * Deprecated tox -downloadcache option removed
  * Fix share size units to match the API
  * API 'manage' can set share attr 'is_public'
  * Updated from global requirements
  * Add python classifiers to setup.cfg
  * Allows type-create to return dict instead of list
  * Updated from global requirements
  * Remove py26 from tox config
  * Delete python bytecode before every test run
  * Updated from global requirements
  * Fix client backwards compatibility
  * Updated from global requirements
  * Add support of new API URLs after port of extensions to core API
  * Nova Style API Version Support for Client
  * Manila list shows one export location not multiple
  * Wrong help for 'manila cg-snapshot-create' command
  * Fix usage of setUpClass method in functional tests
  * Updated from global requirements
  * Add useful links to project README.rst
  * Add support for enable/disable service API
- Adjust Requires according to requirements.txt
* Mon Nov 16 2015 tbechtold@suse.com
- update to 1.5.0:
  * Add Keystone v3 API support
  * Incorrect help of export_path for the manage utility
  * Updated from global requirements
  * Fix args parsing for quota-class-update
  * Change Manilaclient to use --os-region-name param
  * Updated from global requirements
* Fri Sep 25 2015 tbechtold@suse.com
- update to 1.4.0:
  * Fix shares CLI for using CGs
  * Workaround broken openstack client for functional tests
  * Bump latest supported version to 2.6
  * Add consistency group support to manila client
* Wed Sep 16 2015 tbechtold@suse.com
- update to 1.3.0:
  * Fix client API version to support Manila API
  * Implement Share Instances Admin API
  * Add Share Migration support to Manila Client
  * Update path to subunit2html in post_test_hook
  * Manila REST API Microversion Support for Client
  * Add support of new extra spec 'snapshot_support'
  * Allow user to unset security service params
  * Updated from global requirements
  * Allow user to unset share network params
  * Move requirement Openstack client to test-requirements
  * Updated from global requirements
  * Make spec_driver_handles_share_servers required
  * Modify the manage command prompt information
  * Updated from global requirements
  * Add availability zones support
  * Updated from global requirements
  * Add functional tests for access rules
  * Updated from global requirements
  * Fix post_test_hook and update test-requirements
  * Updated from global requirements
  * Updated from global requirements
  * Updated from global requirements
  * Add share shrink API
  * Updated from global requirements
  * Updated from global requirements
  * Add rw functional tests for shares metadata
  * Add rw functional tests for shares
  * Updated from global requirements
- Adjust Requires according to requirements.txt
* Tue Sep 15 2015 tbechtold@suse.com
- update to 1.2.0:
  * Drop incubating theme from docs
  * Add share extend API
  * Fix configuration for tox 2.0.x
  * Rename functional test module from shares to shares_listing
  * Increase quota for share networks in manila installation
  * Updated from global requirements
  * Updated from global requirements
  * Drop use of 'oslo' namespace package
  * Add rw functional tests for share networks
  * Add rw functional tests for share type extra specs
  * Add rw functional tests for private share types
  * Add rw functional tests for public share types
  * Implement wrapper for ascii table parser from tempest_lib.cli
  * Update README to work with release tools
- Adjust Requires according to requirements.txt
* Fri Jun  5 2015 tbechtold@suse.com
- Move python-ddt Requires to test package
* Wed Jun  3 2015 dmueller@suse.com
- remove tempest-lib dependency
* Mon May  4 2015 dmueller@suse.com
- go back to 1.1.0
* Sun Apr 19 2015 cloud-devel@suse.de
- Update to version python-manilaclient-1.0.4.post1:
  * Uncap library requirements for liberty
  1.0.4
* Wed Apr  8 2015 cloud-devel@suse.de
- Update to version python-manilaclient-1.0.3.post4:
  * Validate required parameters for token-based authentication
  * Improve docstrings for share and snapshot API methods
* Fri Mar 27 2015 cloud-devel@suse.de
- Update to version python-manilaclient-1.0.3.post1:
  * Updated from global requirements
  1.0.3
  * Implement private share_types
  * Print share export locations more pretty
  * Make public shares visible for all tenants
  * Add Manila client and CLI support for listing scheduler pools
* Thu Mar 19 2015 rsalevsky@suse.com
- Update to version python-manilaclient-1.0.2.post48:
  * Remove workaround from type_create() shell command
  * Add basic manage/unmanage share functionality
  * Updated from global requirements
  * Manila access-allow CLI command doesn't accept backslash
  * Make extra spec driver_handles_share_servers required
  * Remove redundant call to API in ShareType.get_keys() method
  * Add support of snapshot gigabytes quotas
  * Add support of nova network to share networks
  * Add keystone-session support
* Mon Feb 23 2015 cloud-devel@suse.de
- Update to version python-manilaclient-1.0.2.post33:
  * Updated from global requirements
* Sat Feb 21 2015 cloud-devel@suse.de
- Update to version python-manilaclient-1.0.2.post32:
  * Add is_default column to type-list command output
* Fri Feb 20 2015 cloud-devel@suse.de
- Update to version python-manilaclient-1.0.2.post31:
  * Rename volume_type to share_type
* Thu Feb 19 2015 cloud-devel@suse.de
- Update to version python-manilaclient-1.0.2.post30:
  * Updated from global requirements
* Mon Feb 16 2015 cloud-devel@suse.de
- Update to version python-manilaclient-1.0.2.post29:
  * Add hint for HDFS protocol while creating shares
  * Add -d short option for --debug
* Sat Jan 31 2015 cloud-devel@suse.de
- Update to version python-manilaclient-1.0.2.post26:
  * Print expected and actual request body in fake client
  * Add support of arg "access_level" to allow_access operation
* Fri Jan 30 2015 cloud-devel@suse.de
- Update to version python-manilaclient-1.0.2.post22:
  * Remove links field from Manila client share details output
  * Updated from global requirements
* Sat Jan 24 2015 cloud-devel@suse.de
- Update to version python-manilaclient-1.0.2.post19:
  * Updated from global requirements
  * Add info about functional tests run to docs
* Thu Jan 22 2015 cloud-devel@suse.de
- Update to version python-manilaclient-1.0.2.post16:
  * Fix share-server-list functional test
* Thu Jan 15 2015 cloud-devel@suse.de
- Update to version python-manilaclient-1.0.2.post15:
  * Use print_list and print_dict functions from common code
  * Add read-only functional tests
* Wed Jan 14 2015 cloud-devel@suse.de
- Update to version python-manilaclient-1.0.2.post12:
  * Sync oslo common cliutils code to fix the prints incompatibility in py3
* Wed Jan  7 2015 cloud-devel@suse.de
- Update to version python-manilaclient-1.0.2.post11:
  * Remove nonexistent directory "tests" from pep8 scanning
  * Sync the oslo commom exceptions file to resolve detailed error message
  * Add oslo.utils to requirements.txt
* Mon Jan  5 2015 tbechtold@suse.com
- Update to version python-manilaclient-1.0.2.post6:
  * Add service id to information printed by console client
  * Use six.moves.urllib.parse for py2/3 compat
  * Add manila cli help output to doc
- Add python-oslo.utils as Requires
- Add python-oslo.utils and python-oslo.serialization as
  BuildRequires. Needed to build the documentation
* Mon Dec  8 2014 cloud-devel@suse.de
- Update to version python-manilaclient-1.0.2.1.g8f13562:
  * Workflow documentation is now in infra-manual
  1.0.2
  * Fix common readme info for manilaclient
* Thu Dec  4 2014 cloud-devel@suse.de
- Update to version python-manilaclient-1.0.1.28.g32e7de9:
  * Add 'docs' tox job for generation of docs
  * Remove explicit version definition
  * Make functional tests ci job save testr logs
  * Fix snapshot-list filter key 'usage'
* Thu Nov 20 2014 cloud-devel@suse.de
- Update to version python-manilaclient-1.0.1.dev22.gced8ee7:
  * Updated from global requirements
  * Add gate hook scripts for functional tests
* Thu Nov 13 2014 cloud-devel@suse.de
- Update to version python-manilaclient-1.0.1.dev19.g458888c:
  * Implement functionality for functional tests using tempest-lib
  * Improve documentation
  * Updated from global requirements
  * Add filtering to share-network-list command
* Wed Nov 12 2014 cloud-devel@suse.de
- Update to version python-manilaclient-1.0.1.dev11.g242c8e0:
  * Remove unneeded init file
* Thu Oct 30 2014 cloud-devel@suse.de
- Update to version python-manilaclient-1.0.1.dev10.g5aaecef:
  * Sync with oslo-incubator
* Wed Oct 29 2014 cloud-devel@suse.de
- Update to version python-manilaclient-1.0.1.dev8.ge91b9e6:
  * Improve snapshots list API filtering
* Mon Oct 27 2014 cloud-devel@suse.de
- Update to version python-manilaclient-1.0.1.dev6.gca87081:
  * Use oslo.utils
  * Use oslo.serialization
  * Updated from global requirements
  * Move tests into manilaclient package
  * Add new filters for 'security-service-list' command
* Wed Oct 15 2014 cloud-devel@suse.de
- Update to version python-manilaclient-1.0.1:
  1.0.1
  * Set manilaclient version greater than last release
* Wed Oct 15 2014 cloud-devel@suse.de
- Update to version python-manilaclient-0.1.dev6.gc7456c6:
  * Improve share list API filtering
* Tue Oct 14 2014 cloud-devel@suse.de
- Update to version python-manilaclient-0.1.dev5.g5e71ffc:
  * Handle ambiguous option error for aliases properly
* Fri Oct 10 2014 cloud-devel@suse.de
- Update to version python-manilaclient-0.1.dev4.g5bb1e3b:
  * Work toward Python 3.4 support and testing
* Thu Oct  9 2014 cloud-devel@suse.de
- Update to version python-manilaclient-0.1.dev2.g98de50a:
  1.0.0
  * Add temp files of vim and cover tox job to .gitignore file
* Wed Oct  8 2014 cloud-devel@suse.de
- Update to version python-manilaclient-0.1.dev146.gfc2cd23:
  * Fix endless loop of getattr for share-server instance
* Wed Sep 24 2014 dmueller@suse.com
- Update to version python-manilaclient-0.1.dev145.g33b838a:
  * Use oslosphinx
* Tue Sep 23 2014 cloud-devel@suse.de
- Update to version python-manilaclient-0.1.dev143.gc3bd5b5:
  * Stop using intersphinx
* Sun Sep 21 2014 cloud-devel@suse.de
- Update to version python-manilaclient-0.1.dev141.g88c7e16:
  * Update .gitreview file for move to openstack
* Fri Sep 12 2014 cloud-devel@suse.de
- Update to version python-manilaclient-0.1.dev140.g14f8c85:
  * Add .venv and subunit.log to .gitignore
* Thu Sep 11 2014 cloud-devel@suse.de
- Update to version python-manilaclient-0.1.dev138.g43e0faa:
  * Allow search security services by name too
  * Add GlusterFS protocol as a supported Share/NAS type
* Wed Sep 10 2014 cloud-devel@suse.de
- Update to version python-manilaclient-0.1.dev135.gd70dee0:
  * Warn against sorting requirements
  * Add support for cert-based access type
* Sun Aug 24 2014 cloud-devel@suse.de
- Update to version python-manilaclient-0.1.dev132.g542b59e:
  * Improve help strings
* Fri Aug 22 2014 tbechtold@suse.com
- Update to version python-manilaclient-0.1.dev131.geb81b0f:
  * Print delete errors to stderr
- Only Requires ordereddict on older suse versions
* Mon Aug 18 2014 cloud-devel@suse.de
- Update to version python-manilaclient-0.1.dev129.g0b22b37:
  * Rename 'sid' to 'user' in access rules and sec services
  * Fix deletion of nonexistent share
  * Cleanup manilaclient.utils module (part 2)
  * Cleanup manilaclient.utils module (part 1)
* Mon Aug 11 2014 tbechtold@suse.com
- Initial version of python-manilaclient
